==> wafe-1.0-linux.tar.gz: usr/lib/X11/wafe/tcllib/bc/ATHENA.tcl <==
alias asciiText Text
alias asciiSave XawAsciiSave
alias asciiSaveAsFile XawAsciiSaveAsFile
alias asciiSourceChanged XawAsciiSourceChanged
alias asciiSourceFreeString XawAsciiSourceFreeString
alias box Box
alias clock Clock
alias command Command
alias dialog Dialog
alias dialogGetValueString XawDialogGetValueString
alias form Form
alias formDoLayout XawFormDoLayout
alias grip Grip
alias label Label
alias list List
alias llist list
alias listAppend XawListAppend
alias listChange XawListChange
alias listHighlight XawListHighlight
alias listShowCurrent XawListShowCurrent
alias listUnhighlight XawListUnhighlight
alias logo Logo
alias mailbox Mailbox
alias menuButton MenuButton
alias paned Paned
alias panedAllowResize XawPanedAllowResize
alias panedGetMinMax XawPanedGetMinMax
alias panedGetNumSub XawPanedGetNumSub
alias panedSetMinMax XawPanedSetMinMax
alias panedSetRefigureMode XawPanedSetRefigureMode
alias scrollbar Scrollbar
alias scrollbarSetThumb XawScrollbarSetThumb
alias simpleMenu SimpleMenu
alias simpleMenuClearActiveEntry XawSimpleMenuClearActiveEntry
alias simpleMenuGetActiveEntry XawSimpleMenuGetActiveEntry
alias sme Sme
alias smeBSB SmeBSB
alias smeLine SmeLine
alias stripChart StripChart
alias stripChartSet XawStripChartSet
alias textDisableRedisplay XawTextDisableRedisplay
alias textDisplay XawTextDisplay
alias textDisplayCaret XawTextDisplayCaret
alias textEnableRedisplay XawTextEnableRedisplay
alias textGetInsertionPoint XawTextGetInsertionPoint
alias textGetSelectionPos XawTextGetSelectionPos
alias textInvalidate XawTextInvalidate
alias textSearch XawTextSearch
alias textSetInsertionPoint XawTextSetInsertionPoint
alias textSetSelection XawTextSetSelection
alias textSetSelectionArray XawTextSetSelectionArray
alias textSinkMaxHeight XawTextSinkMaxHeight
alias textSinkMaxLines XawTextSinkMaxLines
alias textSinkSetTabs XawTextSinkSetTabs
alias textSourceRead XawTextSourceRead
alias textSourceScan XawTextSourceScan
alias textTopPosition XawTextTopPosition
alias textReplace XawTextReplace
alias textUnsetSelection XawTextUnsetSelection
alias toggle Toggle
alias toggleChangeRadioGroup XawToggleChangeRadioGroup
alias toggleGetCurrent XawToggleGetCurrent
alias toggleSetCurrent XawToggleSetCurrent
alias toggleSetRadioData XawToggleSetRadioData
alias toggleUnsetCurrent XawToggleUnsetCurrent
alias viewport Viewport
alias viewportSetCoordinates XawViewportSetCoordinates
alias viewportSetLocation XawViewportSetLocation

==> wafe-1.0.13-linux.tar.gz: usr/lib/X11/wafe/tcllib/bc/ATHENA.tcl <==
alias asciiText Text
alias asciiSave XawAsciiSave
alias asciiSaveAsFile XawAsciiSaveAsFile
alias asciiSourceChanged XawAsciiSourceChanged
alias asciiSourceFreeString XawAsciiSourceFreeString
alias box Box
alias clock Clock
alias command Command
alias dialog Dialog
alias dialogGetValueString XawDialogGetValueString
alias form Form
alias formDoLayout XawFormDoLayout
alias grip Grip
alias label Label
alias list List
alias llist list
alias listAppend XawListAppend
alias listChange XawListChange
alias listHighlight XawListHighlight
alias listShowCurrent XawListShowCurrent
alias listUnhighlight XawListUnhighlight
alias logo Logo
alias mailbox Mailbox
alias menuButton MenuButton
alias paned Paned
alias panedAllowResize XawPanedAllowResize
alias panedGetMinMax XawPanedGetMinMax
alias panedGetNumSub XawPanedGetNumSub
alias panedSetMinMax XawPanedSetMinMax
alias panedSetRefigureMode XawPanedSetRefigureMode
alias scrollbar Scrollbar
alias scrollbarSetThumb XawScrollbarSetThumb
alias simple Simple
alias simpleMenu SimpleMenu
alias simpleMenuAddGlobalActions XawSimpleMenuAddGlobalActions
alias simpleMenuClearActiveEntry XawSimpleMenuClearActiveEntry
alias simpleMenuGetActiveEntry XawSimpleMenuGetActiveEntry
alias sme Sme
alias smeBSB SmeBSB
alias smeLine SmeLine
alias stripChart StripChart
alias stripChartSet XawStripChartSet
alias textDisableRedisplay XawTextDisableRedisplay
alias textDisplay XawTextDisplay
alias textDisplayCaret XawTextDisplayCaret
alias textEnableRedisplay XawTextEnableRedisplay
alias textGetInsertionPoint XawTextGetInsertionPoint
alias textGetSelectionPos XawTextGetSelectionPos
alias textInvalidate XawTextInvalidate
alias textSearch XawTextSearch
alias textSetInsertionPoint XawTextSetInsertionPoint
alias textSetSelection XawTextSetSelection
alias textSetSelectionArray XawTextSetSelectionArray
alias textSinkFindDistance XawTextSinkFindDistance
alias textSinkMaxHeight XawTextSinkMaxHeight
alias textSinkMaxLines XawTextSinkMaxLines
alias textSinkSetTabs XawTextSinkSetTabs
alias textSourceRead XawTextSourceRead
alias textSourceScan XawTextSourceScan
alias textTopPosition XawTextTopPosition
alias textReplace XawTextReplace
alias textUnsetSelection XawTextUnsetSelection
alias toggle Toggle
alias toggleChangeRadioGroup XawToggleChangeRadioGroup
alias toggleGetCurrent XawToggleGetCurrent
alias toggleSetCurrent XawToggleSetCurrent
alias toggleSetRadioData XawToggleSetRadioData
alias toggleUnsetCurrent XawToggleUnsetCurrent
alias viewport Viewport
alias viewportSetCoordinates XawViewportSetCoordinates
alias viewportSetLocation XawViewportSetLocation
